/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package examples.invoice.applications;

import org.objectweb.perseus.cache.api.CacheManager;
import org.objectweb.perseus.cache.api.CacheEntry;
import org.objectweb.perseus.cache.api.CacheException;

import java.util.HashMap;

/**
 * @author  P. Dechamboux
 */
public class TrivialCache implements CacheManager {
    private HashMap cache = new HashMap();

    public synchronized CacheEntry bind(Object id, Object entry) throws CacheException {
        CacheEntry ce = (CacheEntry) cache.get(id);
        if (ce == null) {
            ce = new TrivialCacheEntry(id, entry);
            cache.put(id, ce);
        }
        return ce;
    }

    public synchronized CacheEntry lookup(Object id) {
        return (CacheEntry) cache.get(id);
    }

    public void fix(CacheEntry cacheEntry) throws CacheException {
    }

    public void unfix(CacheEntry cacheEntry) throws CacheException {
    }

    public void touch(CacheEntry cacheEntry) throws CacheException {
    }
}

class TrivialCacheEntry implements CacheEntry {
    private Object id;
    private Object entry;

    public TrivialCacheEntry(Object i, Object e) {
        id = i;
        entry = e;
    }

    public Object getCeObject() {
        return null;
    }

    public Object getCeIdentifier() {
        return null;
    }
}
