/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package examples.invoice.persistclass;

import examples.invoice.persistclass.AddressAccessor;
import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PBinding;
import org.objectweb.jorm.api.PException;

/**
 * @author	P. Dechamboux
 */
public class Address implements PAccessor, AddressAccessor, AddressIdPNG {
	private String name;
	private String street;
	private String zip;
	private String town;
	private String country;
	private PBinding pBinding;

	public String pnGetAdrname(Object ctx) throws PException {
		return name;
	}

	public String pnGetAdrtown(Object ctx) throws PException {
		return town;
	}

	public String pnGetAdrstreet(Object ctx) throws PException {
		return street;
	}

	public PBinding getPBinding() {
		return pBinding;
	}

	/**
	 * Creates a new Address.
	 */
	public Address(Object conn, PBinding pb, String n, String s, String z, String t, String c) throws PException {
		pBinding = pb;
		name = n;
		street = s;
		zip = (z == null) ? "38000" : z;
		town = (t == null) ? "Grenoble" : t;
		country = (c == null) ? "France" : c;
		pBinding.export(conn, this);
		pBinding.write(conn, this);
	}

	/**
	 * Creates an Address that is already persistent.
	 */
	public Address(Object conn, PBinding pb) throws PException {
		pBinding = pb;
		pb.read(conn, this);
	}

	/**
	 * Turns this persistent object into a non-persistent one.
	 */
	public void delete(Object conn) throws PException {
		pBinding.unexport(conn);
		pBinding.write(conn, this);
		pBinding = null;
	}

	/**
	 * Yields a printable version a the full Address.
	 */
	public String toPrintable() throws PException {
		return "ID: [" + pBinding.getPName().encodeString() + "] - VALUE: [name: " + name + ", street: " + street + ", zip: " + zip + ", town: " + town + ", country: " + country + "]";
	}

	// IMPLEMENTATION OF PAccessor INTERFACE

	public Object getMemoryInstance() {
		return this;
	}

	// IMPLEMENTATION OF AddressAccessor INTERFACE (generated by JORM)

	// Accessors to the name field
	public void paSetName(String val) throws PException {
		name = val;
	}

	public String paGetName() throws PException {
		return name;
	}

	// Accessors to the zip field
	public void paSetZip(String val) throws PException {
		zip = val;
	}

	public String paGetZip() throws PException {
		return zip;
	}

	// Accessors to the town field
	public void paSetTown(String val) throws PException {
		town = val;
	}

	public String paGetTown() throws PException {
		return town;
	}

	// Accessors to the country field
	public void paSetCountry(String val) throws PException {
		country = val;
	}

	public String paGetCountry() throws PException {
		return country;
	}

	// Accessors to the street field
	public void paSetStreet(String val) throws PException {
		street = val;
	}

	public String paGetStreet() throws PException {
		return street;
	}
}
