/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.facility.naming.generator;

import org.objectweb.jorm.api.PClassMapping;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.api.PMapper;
import org.objectweb.jorm.api.PMapCluster;
import org.objectweb.jorm.facility.naming.basidir.BasidBinder;
import org.objectweb.jorm.naming.api.PBinder;
import org.objectweb.jorm.naming.api.PNamingContext;

/**
 * Manages LongGenIncr long generators. It is extended by the LongGenIncrMapping
 * JORM-generated class.
 * @author	P. Dechamboux
 */
public abstract class LongGenIncrMgr implements LongGenMgr, PClassMapping {
	public final String CNLONGGENINCR = "org.objectweb.jorm.facility.naming.generator.LongGenIncr";

	// IMPLEMENTATION OF METHODS FROM THE LongGenMgr INTERFACE

	/**
	 * Initializes a long generator manager by mapping relevant classes
	 * to the given mapper, and setting relevant initial persistent
	 * information.
	 */
	public void init(PMapper pm, byte clact) throws PException {
		// LongGenIncr initialization
		PClassMapping pcm = pm.lookup(CNLONGGENINCR);
		if (pcm != null)
			throw new PException("LongGenIncr already mapped with this mapper.");
		// Perform mapping only if it has not been already done
		PBinder lgmbinder = new BasidBinder(PNamingContext.CTSTRING);
		setPBinder(lgmbinder);
		lgmbinder.setPClassMapping(this);
		pm.map(this);
		PMapCluster cl = pm.getPMapCluster(this.getClassName());
		if (cl == null) {
			throw new PException("No meta-information cluster defined: not correctly mapped.");
		}
		switch (clact) {
		case PClassMapping.CREATE_STRUCTURE_IF_NEEDED:
			cl.createMappingStructures(false);
			break;
		case PClassMapping.CLEANUP_REMOVEALL:
			cl.deleteMappingStructures();
			cl.createMappingStructures(false);
			break;
		case PClassMapping.CLEANUP_REMOVEDATA:
			cl.deleteData();
			break;
		case PClassMapping.CLEANUP_DONOTHING:
			break;
		}
	}

	/**
	 * Retrieves a long generator with the given name. If it does not
	 * exist, creates it.
	 */
	public LongGen getLongGen(String lgname) throws PException {
		Object conn = getPMapper().getConnection();
		LongGen res;
		try {
			res = (LongGen) Class.forName(getPMapper()
										  .cn2mn(CNLONGGENINCR) + PMapper.PBINDINGAPPENDER)
					.newInstance();
		} catch (Exception e) {
			throw new PException(e, "Cannot create LongGenIncr (probably a ClassLoader problem).");
		}
		res.init(lgname, this, this);
		getPMapper().closeConnection(conn);
		return res;
	}
}
