/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.fos.genclass;

import org.objectweb.jorm.api.PBinding;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.api.PExceptionIO;
import org.objectweb.jorm.api.PExceptionProtocol;
import org.objectweb.jorm.api.PMappingCallback;
import org.objectweb.jorm.genclass.lib.GenClassMapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.mapper.fos.lib.FosPMappingStructuresManager;

import java.io.File;
import java.util.Iterator;

public class FosGenClassMapping
		extends GenClassMapping
		implements FosGenClassProp {
	protected String className = null;
	protected String fieldName = null;
	protected String genClassLevel = null;
	protected String dirName = null;

	private void initDirName() {
		if (dirName == null) {
//			dirName = genClassPType.getJormName();
			dirName = className + File.separator + fieldName + File.separator
					+ genClassLevel;
		}
	}

	// IMPLEMENTATION OF METHODS FROM THE PClassMapping INTERFACE

	/**
	 * It intialises the class mapping. It especially assigns a mapper as well
	 * as a meta-object describing either a class or a generic class.
	 * @param mapper	The mapper to be assigned to this class mapping.
	 * @param metaclass	The meta-object describing the associated class. It may
	 * 					be null.
	 */
	public void init(PMappingCallback mapper, MetaObject metaclass) throws PException {
		super.init(mapper, metaclass);
		initDirName();
		((FosPMappingStructuresManager) mapper.getPMappingStructuresManager())
				.addDirName(genClassPType.getJormName(), dirName);
	}

	/**
	 * It creates a new PBinding.
	 * @return	The new PBinding with lifecycle state set to
	 * 			LIFECYCLE_NOTBOUND.
	 */
	public PBinding createPBinding() throws PException {
		return new FosGenClassBinding(this);
	}

	/**
	 * It returns an iterator over all pname of persitent objects availlable in
	 * this class.
	 * @param conn is the connection which permits to access to the support
	 * @return the iterator over PName objects
	 * @exception PExceptionProtocol	A problem occured during the request
	 * 									that is not related to I/O.
	 * @exception PExceptionIO	A problem occured during the request.
	 */
	public Iterator getPNameIterator(Object conn) throws PException {
		throw new PException("Not supported yet");
	}

	/**
	 * It specifies if the given kind of PMapper is supported by this
	 * PClassMapping.
	 * @param mappername	The name defining the PMapper kind.
	 * @return	true if this kind of mapper is supported.
	 */
	public boolean isConform(String mappername) {
		return mappername.equals("fos");
	}

	// IMPLEMENTATION OF THE METHODS FROM THE FosGenClassProp INTERFACE

	public void setClassName(String cn) {
		className = cn;
	}

	public void setFieldName(String fn) {
		fieldName = fn;
	}

	public void setGenClassLevel(String level) {
		genClassLevel = level;
	}
}
