/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.fos.metainfo;

import org.objectweb.jorm.metainfo.lib.BasicGenClassMapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.GenClassRef;

/**
 * @author	P. Dechamboux
 */
public class FosGenClassMapping extends BasicGenClassMapping
    implements FosMappingInfos {
    private String dirName = null;

    /**
     * Builds a new BasicGenClassMapping.
     * @param linkedMO	the object referenced by the current object,
     * @param parent	the parent of the current object.
     */
    public FosGenClassMapping(MetaObject linkedMO, MetaObject parent) {
        super(null, linkedMO, parent);
    }

    // IMPLEMENTATION OF METHDOS FROM THE FosMappingInfos INTERFACE

    /**
     * Retrieves the name of the directory where class objects
     * are stored.
     * @return  The directory name.
     */
    public String getDirName() {
        return dirName;
    }

    /**
     * Assigns the name of the directory where class objects
     * are stored.
     * @param dirname   The directory name.
     */
    public void setDirName(String dirname) {
        dirName = dirname;
    }

    /**
     * Adds a field mapping for this field with the given name.
     * @param fn    A field name (hidden or not).
     */
    public void addFieldMapping(String fn) {
        GenClassRef gcr = (GenClassRef) getLinkedMO();
        MetaObject f = gcr.getHiddenField(fn);
        if (f != null) {
            if (getPrimitiveElementMapping(fn) == null) {
                addPrimitiveElementMapping(
                        new FosPrimitiveElementMapping(this, f));
            }
        }
    }
}
