/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.adapter;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.api.PExceptionProtocol;

/**
 * @author S.Chassande-Barrioz, J.Camilleri
 */
public class Db2Adapter extends BasicRdbAdapter {

	public Db2Adapter() {
		super();
	}

	public String getSqlType(PType pt, boolean usedInPK, int size) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql Type name associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		// ALL COLUMN IN PK SHOULD BE DECLARED NOT NULL
		case PType.TYPECODE_STRING:
			return (usedInPK
					? "VARCHAR(" + size + ") NOT NULL"
					: "VARCHAR(" + size + ")");
		case PType.TYPECODE_BOOLEAN:
		case PType.TYPECODE_OBJBOOLEAN:
			return (usedInPK
					? "INTEGER NOT NULL"
					: "INTEGER");
		case PType.TYPECODE_CHAR:
		case PType.TYPECODE_OBJCHAR:
			return (usedInPK
					? "CHAR NOT NULL"
					: "CHAR");
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
			return (usedInPK
					? "SMALLINT NOT NULL"
					: "SMALLINT");
		case PType.TYPECODE_SHORT:
		case PType.TYPECODE_OBJSHORT:
			return (usedInPK
					? "SMALLINT NOT NULL"
					: "SMALLINT");
		case PType.TYPECODE_INT:
		case PType.TYPECODE_OBJINT:
			return (usedInPK
					? "INTEGER NOT NULL"
					: "INTEGER");
		case PType.TYPECODE_LONG:
		case PType.TYPECODE_OBJLONG:
			return (usedInPK
					? "BIGINT NOT NULL"
					: "BIGINT");
		case PType.TYPECODE_FLOAT:
		case PType.TYPECODE_OBJFLOAT:
			return (usedInPK
					? "REAL NOT NULL"
					: "REAL");
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
			return (usedInPK
					? "DOUBLE NOT NULL"
					: "DOUBLE");
		case PType.TYPECODE_DATE:
			return (usedInPK
					? "DATE NOT NULL"
					: "DATE");
		case PType.TYPECODE_CHARARRAY:
			return (usedInPK
					? "VARCHAR NOT NULL"
					: "VARCHAR");
		case PType.TYPECODE_BYTEARRAY:
			return (usedInPK
					? "VARCHAR(" + size + ") FOR BIT DATA NOT NULL"
					: "VARCHAR(" + size + ") FOR BIT DATA");
		case PType.TYPECODE_SERIALIZED:
			return (usedInPK
					? "VARCHAR(" + size + ") FOR BIT DATA NOT NULL"
					: "VARCHAR(" + size + ") FOR BIT DATA");
		case PType.TYPECODE_BIGDECIMAL:
			return (usedInPK
					? "DECIMAL NOT NULL"
					: "DECIMAL");
		default:
			return super.getSqlType(pt, usedInPK, size);
		}
	}

	public String getSqlGetterName(PType pt, String resultSet, int idx)
			throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_OBJBYTE:
			return "new Byte(" + resultSet + ".getByte(" + idx + "))";
		case PType.TYPECODE_OBJSHORT:
			return "new Short(" + resultSet + ".getShort(" + idx + "))";
		case PType.TYPECODE_OBJINT:
			return "new Integer(" + resultSet + ".getInt(" + idx + "))";
		default:
			return super.getSqlGetterName(pt, resultSet, idx);
		}
	}

}
