/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.adapter;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.api.PExceptionProtocol;

/**
 * This class is a sql adapter for the Firebird relational database.
 * @author P. Dechamboux
 */
public class FirebirdAdapter extends BasicRdbAdapter {

	public FirebirdAdapter() {
		super();
	}

	public String getSqlType(PType pt, boolean usedInPK, int size) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql Type name associated to a null PType");
		}
		String res;
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BOOLEAN:
		case PType.TYPECODE_OBJBOOLEAN:
			res = "char(1)";
			break;
		case PType.TYPECODE_LONG:
		case PType.TYPECODE_OBJLONG:
			res = "NUMERIC(18)";
			break;
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
			return "SMALLINT";
		case PType.TYPECODE_FLOAT:
		case PType.TYPECODE_OBJFLOAT:
			return "FLOAT";
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
			return "DOUBLE PRECISION";
		case PType.TYPECODE_BYTEARRAY:
//        case PType.TYPECODE_CHARARRAY:
		case PType.TYPECODE_SERIALIZED:
			if (size != PType.NOSIZE) {
				res = "BLOB(" + size + ")";
			}
			res = "BLOB";
			break;
		case PType.TYPECODE_BIGDECIMAL:
			if (size != PType.NOSIZE) {
				res = "DECIMAL(" + size + ",4)";
			}
			return "DECIMAL(18,4)";
		default:
			res = super.getSqlType(pt, usedInPK, size);
		}
		if (usedInPK) {
			res += " NOT NULL";
		}
		return res;
	}

	public String getSqlGetterName(PType pt, String resultSet, int idx,
								   String sql)
			throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BOOLEAN:
			return resultSet + ".getString(" + idx + ").equals(\"T\")";
		case PType.TYPECODE_OBJBOOLEAN:
			return resultSet + ".getString(" + idx + "); fieldval = ((fieldval == null) ? null : new Boolean(((String) fieldval).equals(\"T\")))";
		default:
			return super.getSqlGetterName(pt, resultSet, idx, sql);
		}
	}

	public String getSqlSetterName(PType pt, String value, int idx,
								   String sqlColumnType) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql setter associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BOOLEAN:
			return "setString(" + idx + ", " + value + " ? \"T\" : \"F\")";
		case PType.TYPECODE_OBJBOOLEAN:
			return "setString(" + idx + ", " + value + ".booleanValue() ? \"T\" : \"F\")";
		case PType.TYPECODE_OBJCHAR:
			return "setString(" + idx + ", " + value + ".toString())";
		default:
			return super.getSqlSetterName(pt, value, idx, sqlColumnType);
		}
	}
}
