/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.adapter;

import org.objectweb.jorm.api.PException;

/**
 * This factory permits to create new instances of RdbAdapter.
 * @author	S. Chassande-Barrioz
 */
public class RdbAdapterFactory {
	/**
	 * This constant represents the data base name for a standard jdbc database
	 */
	public static final String DATABASE_NAME_JDBC = "jdbc";

	/**
	 * This first possibility permits to specify the name for which a
	 * RdbAdapter is needed.
	 * @param dbn : the data base name
	 * @return : the type converter linked to the data base name
	 * @exception PException : if the parameter is null or if no RdbAdapter
	 * is associated to the name, a PException is throwing.
	 */
	public static RdbAdapter getTypeConverter(String dbn) throws PException {
		if (dbn == null || dbn.length() == 0 || dbn.equals(DATABASE_NAME_JDBC))
			return new BasicRdbAdapter();
		String n = null;
		try {
			n = "org.objectweb.jorm.mapper.rdb.adapter."
					+ Character.toUpperCase(dbn.charAt(0))
					+ dbn.substring(1, dbn.length()).toLowerCase() + "Adapter";
			return (RdbAdapter) Class.forName(n).newInstance();
		} catch (ClassNotFoundException e) {
		} catch (ClassCastException e) {
			throw new PException(
					"The specified adpater name is not a RdbAdapter: " + n);
		} catch (Exception e) {
			throw new PException(e,
								 "Impossible to instanciate the following rdb adapter class: " + n);
		}
		try {
			return (RdbAdapter) Class.forName(dbn).newInstance();
		} catch (ClassNotFoundException e) {
		} catch (ClassCastException e) {
			throw new PException(
					"The specified adpater name is not a RdbAdapter: " + dbn);
		} catch (Exception e) {
			throw new PException(e,
								 "Impossible to instanciate the following rdb adapter class: " + dbn);
		}

		return new BasicRdbAdapter();
	}
}
