/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.adapter;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.api.PExceptionProtocol;

/**
 * This class is a sql adapter for the SapDB relational database.
 * SapDB 7.4 beta
 * result of the jdbc driver test:
 * ===============================
 * FAIL: BIT: create table: [-3002] (at 31): Invalid datatype
 * FAIL: TINYINT: create table: [-4006] (at 28): Unknown domain name:TINYINT
 * FAIL: SMALLINT: select value 0 with getObject
 * FAIL: SMALLINT: select value 1 with getObject
 * FAIL: SMALLINT: select value 254 with getObject
 * FAIL: INTEGER: select value 0 with getObject
 * FAIL: INTEGER: select value 1 with getObject
 * FAIL: INTEGER: select value 254 with getObject
 * FAIL: BIGINT: create table: [-4006] (at 28): Unknown domain name:BIGINT
 * FAIL: REAL: select value 0.0 with getObject
 * FAIL: REAL: select value 1.0 with getObject
 * FAIL: REAL: select value 254.0 with getObject
 * FAIL: DOUBLE: create table: [-3002] (at 30): Invalid datatype
 *
 * @author S.Chassande-Barrioz
 */
public class SapdbAdapter extends BasicRdbAdapter {

	public SapdbAdapter() {
		super();
	}

	public String getSqlType(PType pt, boolean usedInPK, int size) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql Type name associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BOOLEAN:
		case PType.TYPECODE_OBJBOOLEAN:
			return "?????";
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
			return "?????";
		case PType.TYPECODE_LONG:
		case PType.TYPECODE_OBJLONG:
			return "?????";
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
			return "?????";
		default:
			return super.getSqlType(pt, usedInPK, size);
		}
	}


	public String getSqlGetterName(PType pt, String resultSet, int idx, String sql)
			throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_OBJBYTE:
			//The getObject method is not supported by the TINYINT sql type
			return "new Byte(" + resultSet + ".getByte(" + idx + "))";
		case PType.TYPECODE_OBJSHORT:
			//The getObject method is not supported by the SMALLINT sql type
			return "new Short(" + resultSet + ".getShort(" + idx + "))";
		case PType.TYPECODE_OBJINT:
			//The getObject method is not supported by the INTEGER sql type
			return "new Integer(" + resultSet + ".getInt(" + idx + "))";
		case PType.TYPECODE_OBJLONG:
			//The getObject method is not supported by the BIGINT sql type
			return "new Long(" + resultSet + ".getLong(" + idx + "))";
		case PType.TYPECODE_OBJFLOAT:
			//The getObject method is not supported by the REAL sql type
			return "new Float(" + resultSet + ".getFloat(" + idx + "))";
		case PType.TYPECODE_OBJDOUBLE:
			//The getObject method is not supported by the DOUBLE sql type
			return "new Double(" + resultSet + ".getDouble(" + idx + "))";
		default:
			// The rest is conform to the jdbc specification.
			return super.getSqlGetterName(pt, resultSet, idx, sql);
		}
	}
}
