/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.mapper.rdb.adapter;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.api.PExceptionProtocol;

/**
 * This class is a sql adapter for the Sybase relational database.
 * @author S.Chassande-Barrioz
 */
public class SybaseAdapter extends BasicRdbAdapter {

	public SybaseAdapter() {
		super();
	}

	public String getSqlGetterName(PType pt, String resultSet, int idx, String sql)
			throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_OBJBYTE:
			//The getObject method is not supported by the TINYINT sql type
			return "new Byte(" + resultSet + ".getByte(" + idx + "))";
		case PType.TYPECODE_OBJSHORT:
			//The getObject method is not supported by the SMALLINT sql type
			return "new Short(" + resultSet + ".getShort(" + idx + "))";
		default:
			// The rest is conform to the jdbc specification.
			return super.getSqlGetterName(pt, resultSet, idx, sql);
		}
	}
}
