/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.genclass;

import org.objectweb.jorm.genclass.api.GenClassProp;
import org.objectweb.jorm.mapper.rdb.adapter.RdbAdapter;

/**
 * It dscribes the setters for defining the properties that can be set when
 * initialising a RdbGenClassMapping.
 * @author	P. D?chamboux
 */
public interface RdbGenClassProp extends GenClassProp {
	/**
	 * Defines the table name property of a generic class instance mapped to
	 * a RDB.
	 * @param tn	The table name
	 */
	void setTableName(String tn);

	/**
	 * Defines the type converter property of a generic class instance mapped to
	 * a RDB.
	 * @param adapter	The associated type.
	 */
	void setTypeConverter(RdbAdapter adapter);

	/**
	 * Indicates if the table of the genclass is colocated
	 */
	void setColocated(boolean colocated);

	/**
	 * Indicates if the table of the genclass is colocated
	 */
	void setColocatedMaster(boolean cm);

	/**
	 * Indicates if the table must be only read.
	 * @param readonly
	 */
	void setReadOnly(boolean readonly);
}
