/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.metainfo;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.metainfo.api.HelperClassMapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.PrimitiveElement;
import org.objectweb.jorm.metainfo.api.PrimitiveElementMapping;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class RdbExternalTable extends RdbTable {
    List joins = null;
    List joinNames = null;

    public RdbExternalTable(MetaObject parent, MetaObject linkedMO, String name) {
        super(parent, linkedMO, name);
        joins = new ArrayList();
        joinNames = new ArrayList();
    }

    public RdbJoin createRdbJoin(String jn) {
        RdbJoin j = new RdbJoin(this, jn);
        joins.add(j);
        joinNames.add(jn);
        return j;
    }

    public RdbJoin removeRdbJoin(String j) {
        int idx = joinNames.indexOf(j);
        if (idx != -1) {
            joinNames.remove(idx);
            return (RdbJoin) joins.remove(idx);
        }
        return null;
    }

    public RdbJoin getRdbJoin(String name) {
        int idx = joinNames.indexOf(name);
        if (idx != -1) {
            return (RdbJoin) joins.get(idx);
        }
        return null;
    }

    public Collection getRdbJoins() {
        return joins;
    }

    public RdbPrimitiveElementMapping createPrimitiveElementMapping(
            PrimitiveElement pe,
            String columnName,
            String sqlType,
            boolean notNull,
            RdbJoin join) throws PException {
        RdbPrimitiveElementMapping pem = (RdbPrimitiveElementMapping)
                col2pem.get(columnName);
        if (pem != null) {
            PrimitiveElement p = pem.lookupPrimitiveElement(join);
            if (p != null && p != pe) {
                throw new PException("The column '" + columnName
                                     + "' of the table '" + name + "' is already bound to"
                                     + " another primitive element ("
                                     + (p == null ? null : "'" + p.getName() + "'") + ")"
                                     + " by the join '" + join.getName()
                                     + "' than the specified (" + pe.getName() + ")");
            }
            pem.bindPrimitiveElement(join, pe);
            if (pem.getType() == null && sqlType != null) {
                pem.setType(sqlType);
            }
            pem.setIsNotNull(pem.isNotNull() || notNull);
        }
        RdbPrimitiveElementMapping pem2 = new RdbPrimitiveElementMapping(
                columnName, sqlType, notNull, pe, this, join);
        ((HelperClassMapping) getParent()).addPrimitiveElementMapping(pem2);
        pem2.setLogger(getLogger());
        pem2.setLoggerFactory(getLoggerFactory());
        if (pem == null) {
            col2pem.put(columnName, pem2);
            return pem2;
        }
        return pem;
    }

    public PrimitiveElementMapping getPrimitiveElementMappingByField(String fieldName) {
        for (Iterator it = col2pem.values().iterator(); it.hasNext();) {
            RdbPrimitiveElementMapping pem =
                    (RdbPrimitiveElementMapping) it.next();
            Iterator itPem = pem.getPrimitiveElementByRdbJoin().values().iterator();
            while (itPem.hasNext()) {
                PrimitiveElement pe = (PrimitiveElement) itPem.next();
                if (pe.getName().equals(fieldName))
                    return pem;
            }
        }
        return null;
    }
}
