/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.metainfo;

import org.objectweb.jorm.metainfo.api.Class;
import org.objectweb.jorm.metainfo.api.ClassMapping;
import org.objectweb.jorm.metainfo.api.MappingPrinter;
import org.objectweb.jorm.metainfo.api.MappingStructure;
import org.objectweb.jorm.metainfo.api.PrimitiveElementMapping;
import org.objectweb.jorm.metainfo.api.PrimitiveElement;
import org.objectweb.jorm.metainfo.api.GenClassMapping;
import org.objectweb.jorm.metainfo.api.GenClassRef;
import org.objectweb.jorm.metainfo.lib.MetaInfoPrinter;

import java.io.PrintStream;
import java.util.Iterator;
import java.util.Map;

/**
 * @author S.Chassande-Barrioz
 */
public class RdbMappingPrinter extends MappingPrinter {
	public void print(String p, ClassMapping _cm, PrintStream out) {
		RdbClassMapping cm = (RdbClassMapping) _cm;
		boolean isMulti = cm instanceof RdbClassMultiMapping;
		out.println((isMulti ? "RdbClassMultiMapping: '" : "RdbClassMapping: '")
					+ ((Class) cm.getLinkedMO()).getFQName() + "'");
		print(p, cm.getRdbTable(), out);
		if (isMulti) {
			RdbClassMultiMapping rcm = (RdbClassMultiMapping) cm;
			Iterator it = rcm.getRdbExternalTables().iterator();
			while (it.hasNext()) {
				print(p, (RdbTable) it.next(), out);
			}
		}
		super.print(p, _cm, out);
	}

	public void print(String p, GenClassMapping _gcm, PrintStream out) {
		RdbGenClassMapping gcm = (RdbGenClassMapping) _gcm;
		out.println("RdbGenClassMapping: '" + ((GenClassRef) gcm.getLinkedMO()).getGenClassId() + "'");
		print(p, gcm.getRdbTable(), out);
		super.print(p, gcm, out);
	}

	public void print(String p, PrimitiveElementMapping pem, PrintStream out) {
		RdbPrimitiveElementMapping rpem = (RdbPrimitiveElementMapping) pem;
		Map m = rpem.getPrimitiveElementByRdbJoin();
		PrimitiveElement pe;
		if (m == null || m.size() <= 1) {
			pe = (PrimitiveElement) pem.getLinkedMO();
			out.println(p + "Column '" + rpem.getName() + "' / field '" + pe.getName());
		} else {
			out.print(p + "Column '" + rpem.getName() + "'");
			Iterator it = m.entrySet().iterator();
			String sep = " / ";
			while (it.hasNext()) {
				Map.Entry me = (Map.Entry) it.next();
				RdbJoin j = (RdbJoin) me.getKey();
				pe = (PrimitiveElement) me.getValue();
				out.print(sep + "(field:" + pe.getName() + ", join:" + j.getName() + ")");
				sep = ", ";
			}
			out.println();
		}
	}

	public boolean canPrint(MappingStructure ms) {
		return true;//ms.getMapperName().startsWith("rdb");
	}

	public void print(String p, RdbTable t, PrintStream out) {
		boolean isExternal = t instanceof RdbExternalTable;
		out.println(p + (isExternal ? "External" : "Main")
					+ " table: " + t.getName()
					+ " colocated:" + t.isColocated()
					+ " colocatedMaster:" + t.isColocatedMaster()
					+ " readOnly:" + t.isReadOnly()
		);
		Iterator it = t.getPrimitiveElementMappings().iterator();
		while (it.hasNext()) {
			print(p + MetaInfoPrinter.TAB,
				  (PrimitiveElementMapping) it.next(), out);
		}
		if (isExternal) {
			it = ((RdbExternalTable) t).getRdbJoins().iterator();
			while (it.hasNext()) {
				RdbJoin j = (RdbJoin) it.next();
				out.println(p + "Join '" + j.getName() + "': " + j.getPTJoinColumnNames() + " == " + j.getETJoinColumnNames());
			}
		}
	}
}
