/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.mapper.rdb.metainfo;

import org.objectweb.jorm.metainfo.api.PrimitiveElement;
import org.objectweb.jorm.metainfo.api.PrimitiveElementMapping;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.metainfo.api.HelperClassMapping;
import org.objectweb.jorm.metainfo.lib.BasicMappingStructure;
import org.objectweb.jorm.api.PException;

import java.util.Collection;
import java.util.Map;
import java.util.HashMap;
import java.util.Iterator;

/**
 *
 * @author S.Chassande-Barrioz
 */
public class RdbTable extends BasicMappingStructure {
	String name = null;
	boolean colocated = false;
	boolean colocatedMaster = false;
	Map col2pem = null;
	boolean readOnly;

	public RdbTable(MetaObject parent, MetaObject linkedMO, String name) {
		super(parent, linkedMO);
		col2pem = new HashMap();
		this.name = name;
	}


	//IMPLEMENTATON OF THE rdbTable INTERFACE //
	//----------------------------------------//

	public boolean isReadOnly() {
		return readOnly;
	}

	public void setReadOnly(boolean readOnly) {
		this.readOnly = readOnly;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Collection getPrimitiveElementMappings() {
		return col2pem.values();
	}

	public RdbPrimitiveElementMapping createPrimitiveElementMapping(
			PrimitiveElement pe,
			String columnName,
			String sqlType,
			boolean notNull) throws PException {
		RdbPrimitiveElementMapping pem = (RdbPrimitiveElementMapping)
				col2pem.get(columnName);
		if (pem != null) {
			throw new PException("Column " + columnName
								 + " already defined in the table " + name);
		}
		pem = new RdbPrimitiveElementMapping(
				columnName, sqlType, notNull, pe, this);
		((HelperClassMapping) getParent()).addPrimitiveElementMapping(pem);
		pem.setLogger(getLogger());
		pem.setLoggerFactory(getLoggerFactory());
		col2pem.put(columnName, pem);
		return pem;
	}

	public RdbPrimitiveElementMapping createPrimitiveElementMapping(
			PrimitiveElement pe,
			String columnName) throws PException {
		return createPrimitiveElementMapping(pe, columnName, null, false);
	}

	public PrimitiveElementMapping removePrimitiveElementMapping(PrimitiveElementMapping pe) {
		return (PrimitiveElementMapping) col2pem.remove(pe);
	}

	public PrimitiveElementMapping getPrimitiveElementMappingByCol(String columnName) {
		return (PrimitiveElementMapping) col2pem.get(columnName);
	}

	public PrimitiveElementMapping getPrimitiveElementMappingByField(String fieldName) {
		for (Iterator it = col2pem.values().iterator(); it.hasNext();) {
			RdbPrimitiveElementMapping pem =
					(RdbPrimitiveElementMapping) it.next();
			if (((PrimitiveElement) pem.getLinkedMO()).getName().equals(fieldName))
				return pem;
		}
		return null;
	}

	public boolean isColocated() {
		return colocated;
	}

	public void setColocated(boolean c) {
		colocated = c;
	}

	public boolean isColocatedMaster() {
		return colocatedMaster;
	}

	public void setColocatedMaster(boolean cm) {
		colocatedMaster = cm;
	}
}
