/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.api;

import java.util.Iterator;
import java.util.Collection;

/**
 * The ClassMapping interface defines methods to describe how a
 * class is mapped into JORM.
 * @author	X. Spengler
 */
public interface ClassMapping extends HelperClassMapping {
	/**
	 * Adds a ReferenceMapping object.
	 *
	 * @param  refMapping  the ReferenceMapping object to add to the list.
	 */
	void addReferenceMapping(ReferenceMapping refMapping);

	/**
	 * Retrieves the ReferenceMapping instance corresponding to the name of
	 * a reference field.
	 * @param referenceName is the name of a reference field
	 * @return a ReferenceMapping instance or a null value if no mapping is
	 * defined for the reference name
	 */
	ReferenceMapping getReferenceMapping(String referenceName);

	/**
	 * Returns an Iterator over ReferenceMapping objects.
	 *
	 * @return  an Iterator.
	 */
	Iterator iterateReferenceMappings();

	/**
	 * Returns a collection of ReferenceMapping objects.
	 *
	 * @return  a collection.
	 */
	Collection getReferenceMappings();

}
