/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.api;

import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.jorm.util.api.Loggable;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.LoggerFactory;

/**
 * todo: Description
 */
public interface MappingStructure extends MetaObject, Loggable {
	/**
	 * Returns the MetaObject referenced by the current MetaObject.
	 * @return	the MetaObject referenced by the current object. If there is
	 *          no referenced object, null is returned.
	 */
	MetaObject getLinkedMO();

	/**
	 * Sets the MetaObject referenced by the current MetaObject.
	 * @param refMO	  the MetaObject referenced by the current object
	 */
	void setLinkedMO(MetaObject refMO);

	/**
	 * Returns the mapper name.
	 * @return the mapper name.
	 */
	public String getMapperName();

	/**
	 * Returns the project name.
	 * @return the project name.
	 */
	public String getProjectName();

	///////////////////////////////////////////////////////////////////
	//                      from Loggable interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Defines a logger object.
	 * @param logger	the logger object
	 */
	public void setLogger(Logger logger);

	/**
	 * Defines the logger factory to obtain new logger.
	 * @param loggerFactory	the LoggerFactory object to obtain a logger object
	 */
	public void setLoggerFactory(LoggerFactory loggerFactory);

	public Logger getLogger();

	public LoggerFactory getLoggerFactory();
}
