/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.metainfo.lib;

import org.objectweb.jorm.metainfo.api.FieldName;
import org.objectweb.jorm.metainfo.api.MetaObject;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.LoggerFactory;
import org.objectweb.jorm.util.api.Loggable;

/**
 * The FieldName object defines methods to reference an already existing Field.
 * @author	X. Spengler
 */
public class BasicFieldName implements FieldName, Loggable {
	/**
	 * the name of the field
	 */
	private String fieldName;

	/**
	 * the parent of the current object
	 */
	private MetaObject parent;

	/**
	 * a simple logger to log
	 */
	private transient Logger logger;

	/**
	 * Builds a new BasicFieldName object.
	 *
	 * @param field the name of the field
	 * @param parent    the parent of the current object
	 */
	public BasicFieldName(String field, MetaObject parent) {
		fieldName = field;
		this.parent = parent;
	}

	///////////////////////////////////////////////////////////////////
	//                      from FieldName interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Returns the name of the referenced field.
	 *
	 * @return	the string representation of the referenced field
	 */
	public String getField() {
		return fieldName;
	}

	/**
	 * Allows to set the name of the referenced field.
	 *
	 * @param field the string representation of the referenced field
	 */
	public void setField(String field) {
		fieldName = field;
	}

	///////////////////////////////////////////////////////////////////
	//                      from Loggable interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Defines a logger object.
	 *
	 * @param logger	the logger object
	 */
	public void setLogger(Logger logger) {
		this.logger = logger;
	}

	/**
	 * Defines the logger factory to obtain new logger.
	 *
	 * @param loggerFactory	the LoggerFactory object to obtain a logger object
	 */
	public void setLoggerFactory(LoggerFactory loggerFactory) {
	}

	public Logger getLogger() {
		return logger;
	}

	public LoggerFactory getLoggerFactory() {
		return null;
	}

	///////////////////////////////////////////////////////////////////
	//                      from MetaObject interface
	///////////////////////////////////////////////////////////////////

	/**
	 * Allows to know the parent MetaObject of the current MetaObject.
	 *
	 * @return	the MetaObject corresponding to the parent of the
	 *  		current object. If there is no parent, null is returned.
	 */
	public MetaObject getParent() {
		return parent;
	}

	/**
	 * Set the parent of the current meta object if it is not yet done
	 * by the constructor of the meta object
	 * @param itsParent	the parent MetaObject of the current object
	 */
	public void setParent(MetaObject itsParent) {
		this.parent = itsParent;
	}

}
