/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.naming.api;

import java.util.Date;

/**
 * Used to encode/decode a composite name to/from a String. For the decode
 * process, there are the typed getter methods (XXX getXXX()). It supposes that
 * the coder knows the String representing the encoded value. For the encode
 * process, there are the setter methods (putXXX(XXX val)) in order to add
 * new sub values to the encoded String. After all putXXX has been done, the
 * encoded value is retrieved using the getStringCode method.
 * @author	P. D?chamboux
 */
public interface PNCStringCoder {
	byte getByte() throws PExceptionCoder;

	Byte getObyte() throws PExceptionCoder;

	char getChar() throws PExceptionCoder;

	Character getOchar() throws PExceptionCoder;

	short getShort() throws PExceptionCoder;

	Short getOshort() throws PExceptionCoder;

	int getInt() throws PExceptionCoder;

	Integer getOint() throws PExceptionCoder;

	long getLong() throws PExceptionCoder;

	Long getOlong() throws PExceptionCoder;

	String getString() throws PExceptionCoder;

	Date getDate() throws PExceptionCoder;

	byte[] getByteArray() throws PExceptionCoder;

	char[] getCharArray() throws PExceptionCoder;

	void putByte(byte val) throws PExceptionCoder;

	void putObyte(Byte val) throws PExceptionCoder;

	void putChar(char val) throws PExceptionCoder;

	void putOchar(Character val) throws PExceptionCoder;

	void putShort(short val) throws PExceptionCoder;

	void putOshort(Short val) throws PExceptionCoder;

	void putInt(int val) throws PExceptionCoder;

	void putOint(Integer val) throws PExceptionCoder;

	void putLong(long val) throws PExceptionCoder;

	void putOlong(Long val) throws PExceptionCoder;

	void putString(String val) throws PExceptionCoder;

	void putDate(Date val) throws PExceptionCoder;

	void putByteArray(byte[] val) throws PExceptionCoder;

	void putCharArray(char[] val) throws PExceptionCoder;

	String getStringCode() throws PExceptionCoder;
}
