/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.naming.lib;

import org.objectweb.jorm.naming.api.PNamingContext;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.type.api.PType;

import java.util.Date;

/**
 * Default implementation for a PNamingContext with no coding support.
 * @author	P. D?chamboux
 */
public abstract class BasicPNamingContext implements PNamingContext {
	protected PType ptype = null;

	public PType getPType() {
		return ptype;
	}

	public void setPType(PType pt) {
		ptype = pt;
	}

	public boolean codingSupported(short codingtype) {
		return false;
	}

	public PName decode(byte[] en) throws PExceptionNaming {
		return null;
	}

	public PName decodeCharArray(char[] en) throws PExceptionNaming {
		throw new UnsupportedOperationException("char[] coding not supported");
	}

	public PName decodeAbstract(Object en, Object context) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("abstract coding not supported");
	}

	public PName decodeByte(byte en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("byte coding not supported");
	}

	public PName decodeObyte(Byte en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Byte coding not supported");
	}

	public PName decodeChar(char en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("char coding not supported");
	}

	public PName decodeOchar(Character en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Character coding not supported");
	}

	public PName decodeInt(int en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("int coding not supported");
	}

	public PName decodeOint(Integer en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Integer coding not supported");
	}

	public PName decodeLong(long en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("long coding not supported");
	}

	public PName decodeOlong(Long en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Long coding not supported");
	}

	public PName decodeShort(short en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("short coding not supported");
	}

	public PName decodeOshort(Short en) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Short coding not supported");
	}

	public PName decodeDate(Date en) throws PExceptionNaming {
		throw new UnsupportedOperationException("date coding not supported");
	}

	public byte[] encode(PName pn) throws PExceptionNaming {
		return null;
	}

	public char[] encodeCharArray(PName pn) throws PExceptionNaming {
		throw new UnsupportedOperationException("char[] coding not supported");
	}

	public Object encodeAbstract(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("abstract coding not supported");
	}

	public byte encodeByte(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("byte coding not supported");
	}

	public Byte encodeObyte(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Byte coding not supported");
	}

	public char encodeChar(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("char coding not supported");
	}

	public Character encodeOchar(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Character coding not supported");
	}

	public int encodeInt(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("int coding not supported");
	}

	public Integer encodeOint(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Integer coding not supported");
	}

	public long encodeLong(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("long coding not supported");
	}

	public Long encodeOlong(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Long coding not supported");
	}

	public short encodeShort(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("short coding not supported");
	}

	public Short encodeOshort(PName pn) throws PExceptionNaming, UnsupportedOperationException {
		throw new UnsupportedOperationException("Short coding not supported");
	}

	public Date encodeDate(PName pn) throws PExceptionNaming {
		throw new UnsupportedOperationException("date coding not supported");
	}

	public boolean supportDynamicComposite() {
		return false;
	}

	public boolean supportCompositeField(String fn, PType ft) {
		return false;
	}

	public boolean supportStaticComposite() {
		return false;
	}
}
